Changelog
=========

Next
----

2024.10.14.1
------------

2024.10.14
----------

* Add documentation and source links to PyPI.

2024.10.13.1
------------

* Output in color (not yet on Windows).

2024.10.12
----------

* Only log ``--verbose`` messages when the relevant example will be run and is not a skip directive.

2024.10.11
----------

* Use line endings from the original file.
